@@ -2,6 +2,8 @@ from typing import List, Optional
 
 from pyspark.sql import DataFrame
 from pyspark.sql.functions import monotonically_increasing_id
+# noinspection PyUnresolvedReferences
+from pyspark.sql.functions import col
 
 from spark_auto_mapper.automappers.automapper_base import AutoMapperBase
 from spark_auto_mapper.automappers.container import AutoMapperContainer
@@ -41,9 +43,19 @@ class AutoMapper(AutoMapperContainer):
     ) -> DataFrame:
         # iterate over each child mapper and run it
         for column_name, child_mapper in self.mappers.items():
-            df = child_mapper.transform_with_data_frame(
-                df=df, source_df=source_df, keys=keys
-            )
+            try:
+                df = child_mapper.transform_with_data_frame(
+                    df=df, source_df=source_df, keys=keys
+                )
+            except Exception as e:
+                # write out the full list of columns
+                columns_in_source: List[str] = list(source_df.columns)
+                columns_in_destination: List[str] = list(df.columns)
+                msg: str = str(e)
+                msg += f", Processing column:[{column_name}]"
+                msg += f", Source columns:[{','.join(columns_in_source)}]"
+                msg += f", Destination columns:[{','.join(columns_in_destination)}]"
+                raise Exception(msg) from e
         return df
 
     def transform(self, df: DataFrame) -> DataFrame:
@@ -66,18 +78,51 @@ class AutoMapper(AutoMapperContainer):
         destination_df: DataFrame = df.sql_ctx.table(self.view) \
             if self.view and SparkHelpers.spark_table_exists(sql_ctx=df.sql_ctx, view=self.view) \
             else source_df.select(self.keys)
+
+        # rename key columns to avoid name clash if someone creates a column with that name
+        renamed_key_columns: List[str] = []
+        for key in self.keys:
+            renamed_key_column: str = f"__{key}"
+            source_df = source_df.withColumn(renamed_key_column, col(key))
+            try:
+                destination_df = destination_df.withColumn(
+                    renamed_key_column, col(key)
+                )
+            except Exception as e:
+                # write out the full list of columns
+                columns_in_source: List[str] = list(source_df.columns)
+                columns_in_destination: List[str] = list(
+                    destination_df.columns
+                )
+                msg: str = str(e)
+                msg += f", Source columns:[{','.join(columns_in_source)}]"
+                msg += f", Destination columns:[{','.join(columns_in_destination)}]"
+                raise Exception(msg) from e
+            renamed_key_columns.append(renamed_key_column)
+
         # run the mapper
         result_df: DataFrame = self.transform_with_data_frame(
-            df=destination_df, source_df=source_df, keys=self.keys
+            df=destination_df, source_df=source_df, keys=renamed_key_columns
         )
 
-        # # now drop the __row_id if we added it
-        # result_df = result_df.drop(TEMPORARY_KEY)
+        # now drop the __row_id if we added it
+        result_df = result_df.drop(TEMPORARY_KEY)
 
         # drop the key columns
         if self.drop_key_columns:
             result_df = result_df.drop(*self.keys)
 
+        # drop the renamed key columns
+        result_df = result_df.drop(*renamed_key_columns)
+
+        # replace any columns we had prepended with "___" to avoid a name clash with key columns
+        for column_name in [
+            c for c in result_df.columns if c.startswith("___")
+        ]:
+            result_df = result_df.withColumnRenamed(
+                column_name, column_name.replace("___", "")
+            )
+
         # remove duplicates
         if not self.keep_duplicates:
             result_df = result_df.drop_duplicates()
