@@ -1,5 +1,7 @@
 from typing import Any, Dict, Union, TypeVar, cast, Optional
 
+from spark_auto_mapper.data_types.text_like_base import AutoMapperTextLikeBase
+
 from spark_auto_mapper.data_types.amount import AutoMapperAmountDataType
 from spark_auto_mapper.data_types.boolean import AutoMapperBooleanDataType
 from spark_auto_mapper.data_types.column import AutoMapperDataTypeColumn
@@ -12,9 +14,11 @@ from spark_auto_mapper.data_types.if_not_null import AutoMapperIfNotNullDataType
 from spark_auto_mapper.data_types.literal import AutoMapperDataTypeLiteral
 from spark_auto_mapper.data_types.map import AutoMapperMapDataType
 from spark_auto_mapper.data_types.number import AutoMapperNumberDataType
-from spark_auto_mapper.data_types.complex.struct import AutoMapperDataTypeStruct
+from spark_auto_mapper.data_types.complex.struct_type import AutoMapperDataTypeStruct
+from spark_auto_mapper.data_types.regex_replace import AutoMapperRegExReplaceDataType
 from spark_auto_mapper.data_types.substring import AutoMapperSubstringDataType
 from spark_auto_mapper.data_types.substring_by_delimiter import AutoMapperSubstringByDelimiterDataType
+from spark_auto_mapper.data_types.trim import AutoMapperTrimDataType
 from spark_auto_mapper.type_definitions.defined_types import AutoMapperAnyDataType, AutoMapperBooleanInputType, \
     AutoMapperAmountInputType, AutoMapperNumberInputType, AutoMapperDateInputType
 from spark_auto_mapper.type_definitions.native_types import AutoMapperNativeTextType, AutoMapperNativeSimpleType
@@ -116,7 +120,8 @@ class AutoMapperHelpers:
 
     @staticmethod
     def concat(
-        *args: Union[AutoMapperNativeTextType, AutoMapperWrapperType]
+        *args: Union[AutoMapperNativeTextType, AutoMapperWrapperType,
+                     AutoMapperTextLikeBase]
     ) -> AutoMapperConcatDataType:
         """
         concatenates a list of values.  Each value can be a string or a column
@@ -164,7 +169,8 @@ class AutoMapperHelpers:
 
     @staticmethod
     def left(
-        column: AutoMapperDataTypeColumn, length: int
+        column: Union[AutoMapperDataTypeColumn, AutoMapperTextLikeBase],
+        length: int
     ) -> AutoMapperSubstringDataType:
         """
         Take the specified number of first characters in a string
@@ -179,7 +185,8 @@ class AutoMapperHelpers:
 
     @staticmethod
     def right(
-        column: AutoMapperDataTypeColumn, length: int
+        column: Union[AutoMapperDataTypeColumn, AutoMapperTextLikeBase],
+        length: int
     ) -> AutoMapperSubstringDataType:
         """
         Take the specified number of last characters in a string
@@ -194,7 +201,8 @@ class AutoMapperHelpers:
 
     @staticmethod
     def substring(
-        column: AutoMapperDataTypeColumn, start: int, length: int
+        column: Union[AutoMapperDataTypeColumn, AutoMapperTextLikeBase],
+        start: int, length: int
     ) -> AutoMapperSubstringDataType:
         """
         Finds a substring in the specified string.
@@ -210,7 +218,8 @@ class AutoMapperHelpers:
 
     @staticmethod
     def string_before_delimiter(
-        column: AutoMapperDataTypeColumn, delimiter: str
+        column: Union[AutoMapperDataTypeColumn, AutoMapperTextLikeBase],
+        delimiter: str
     ) -> AutoMapperSubstringByDelimiterDataType:
         """
         Take the specified number of first characters in a string
@@ -225,7 +234,8 @@ class AutoMapperHelpers:
 
     @staticmethod
     def string_after_delimiter(
-        column: AutoMapperDataTypeColumn, delimiter: str
+        column: Union[AutoMapperDataTypeColumn, AutoMapperTextLikeBase],
+        delimiter: str
     ) -> AutoMapperSubstringByDelimiterDataType:
         """
         Take the specified number of first characters in a string
@@ -240,7 +250,8 @@ class AutoMapperHelpers:
 
     @staticmethod
     def substring_by_delimiter(
-        column: AutoMapperDataTypeColumn, delimiter: str, delimiter_count: int
+        column: Union[AutoMapperDataTypeColumn, AutoMapperTextLikeBase],
+        delimiter: str, delimiter_count: int
     ) -> AutoMapperSubstringByDelimiterDataType:
         """
         Returns the substring from string str before count occurrences of the delimiter.
@@ -259,3 +270,32 @@ class AutoMapperHelpers:
             delimiter=delimiter,
             delimiter_count=delimiter_count
         )
+
+    @staticmethod
+    def regex_replace(
+        column: Union[AutoMapperDataTypeColumn, AutoMapperTextLikeBase],
+        pattern: str, replacement: str
+    ) -> AutoMapperRegExReplaceDataType:
+        """
+        Replace all substrings of the specified string value that match regexp with rep.
+
+        :param column: column whose contents to replace
+        :param pattern: pattern to search for
+        :param replacement: string to replace with
+        :return: a regex_replace automapper type
+        """
+        return AutoMapperRegExReplaceDataType(
+            column=column, pattern=pattern, replacement=replacement
+        )
+
+    @staticmethod
+    def trim(
+        column: Union[AutoMapperDataTypeColumn, AutoMapperTextLikeBase]
+    ) -> AutoMapperTrimDataType:
+        """
+        Trim the spaces from both ends for the specified string column.
+
+        :param column: column whose contents to trim
+        :return: a trim automapper type
+        """
+        return AutoMapperTrimDataType(column=column)
